install_plugins

Function install_plugins 

pub fn install_plugins(ctx: &Ctx<'_>, files: &[PluginBinding]) -> Result<()>
Install loaded plugins: load+evaluate each file’s bytecode (which registers its tools into the shared registry, native or legacy shape), then expose every registered tool as a native plugins.<name> callable.