pub struct AsyncContext(/* private fields */);Expand description
An asynchronous single execution context with its own global variables and stack.
Can share objects with other contexts of the same runtime.
Implementations
Sourceimpl AsyncContext
impl AsyncContext
Sourcepub unsafe fn from_raw(
ctx: NonNull<JSContext>,
rt: AsyncRuntime,
) -> AsyncContext
pub unsafe fn from_raw( ctx: NonNull<JSContext>, rt: AsyncRuntime, ) -> AsyncContext
Create a async context form a raw context pointer.
Safety
The context must be of the correct runtime. The context must also have valid reference count, one which can be decremented when this object is dropped without going negative.
Sourcepub async fn base(runtime: &AsyncRuntime) -> Result<AsyncContext, Error>
pub async fn base(runtime: &AsyncRuntime) -> Result<AsyncContext, Error>
Creates a base context with only the required functions registered.
If additional functions are required use AsyncContext::custom,
AsyncContext::builder or AsyncContext::full.
Sourcepub async fn custom<I>(runtime: &AsyncRuntime) -> Result<AsyncContext, Error>where
I: Intrinsic,
pub async fn custom<I>(runtime: &AsyncRuntime) -> Result<AsyncContext, Error>where
I: Intrinsic,
Creates a context with only the required intrinsics registered.
If additional functions are required use AsyncContext::custom,
AsyncContext::builder or AsyncContext::full.
Sourcepub async fn full(runtime: &AsyncRuntime) -> Result<AsyncContext, Error>
pub async fn full(runtime: &AsyncRuntime) -> Result<AsyncContext, Error>
Creates a context with all standard available intrinsics registered.
If precise control is required of which functions are available use
AsyncContext::custom or AsyncContext::builder.
Sourcepub fn builder() -> ContextBuilder<()>
pub fn builder() -> ContextBuilder<()>
Create a context builder for creating a context with a specific set of intrinsics
Sourcepub fn runtime(&self) -> &AsyncRuntime
pub fn runtime(&self) -> &AsyncRuntime
Returns the associated runtime
Sourcepub fn async_with<F, R>(&self, f: F) -> WithFuture<'_, F, R>where
F: for<'js> FnOnce(Ctx<'js>) -> Pin<Box<dyn Future<Output = R> + Send + 'js>> + ParallelSend,
R: ParallelSend,
pub fn async_with<F, R>(&self, f: F) -> WithFuture<'_, F, R>where
F: for<'js> FnOnce(Ctx<'js>) -> Pin<Box<dyn Future<Output = R> + Send + 'js>> + ParallelSend,
R: ParallelSend,
A entry point for manipulating and using JavaScript objects and scripts.
This function is rather limited in what environment it can capture. If you need to borrow
the environment in the closure use the async_with! macro.
Unfortunately it is currently impossible to have closures return a generic future which has a higher rank trait bound lifetime. So, to allow closures to work, the closure must return a boxed future.
Sourcepub async fn with<F, R>(&self, f: F) -> R
pub async fn with<F, R>(&self, f: F) -> R
A entry point for manipulating and using JavaScript objects and scripts.
This closure can’t return a future, if you need to await JavaScript promises prefer the
async_with! macro.